Struct ergo_headless_dapp_framework::box_spec::BoxSpec
source · [−]pub struct BoxSpec { /* private fields */ }Expand description
A specification which specifies parameters of an ErgoBox.
This spec is used as a “source of truth” to both verify and find
ErgoBoxes which match the spec. This is often used for defining
Stages in multi-stage smart contract protocols, but can also be used
to define input boxes for Actions.
All fields are wrapped in Options to allow ignoring specifying
the field.
Implementations
Method definitions for BoxSpec that are WASM-compatible by default
and/or are wrapper functions for Rust methods so that they
are made WASM-compatible.
Returns a new BoxSpec with all fields exactly the same
except the address is set to the String provided as input.
This method is generally used to hone down a more generic
BoxSpec definition into a more specific one for your given
use case. Ie. Add a user’s P2PK address to find boxes matching
the BoxSpec in their wallet.
Method definitions for BoxSpec that are intended to be used in
Rust.
Create a new basic BoxSpec with no predicate.
Create a new BoxSpec with a custom predicate defined.
Verify that a provided ErgoBox matches the spec
Generates a URL for the Ergo Explorer Backend API
to find boxes which may match your BoxSpec. This method uses
the explorer_api_url you provide as input which
must be formatted as such:
https://api.ergoplatform.com/api
This method is intended to be used in tandem with
process_explorer_response()
Methods related to modifying fields (which aren’t WASM-compatible)
Returns a new BoxSpec with all fields exactly the same
except the value_range is set to the range provided as input.
Returns a new BoxSpec with all fields exactly the same
except the registers are set to the registers provided as input.
Returns a new BoxSpec with all fields exactly the same
except the tokens are set to the TokenSpecs provided as input.