[−][src]Struct ergo_headless_dapp_framework::UnsignedTransaction
Unsigned (inputs without proofs) transaction
Fields
inputs: Vec<UnsignedInput, Global>unsigned inputs, that will be spent by this transaction.
data_inputs: Vec<DataInput, Global>inputs, that are not going to be spent by transaction, but will be reachable from inputs
scripts. dataInputs scripts will not be executed, thus their scripts costs are not
included in transaction cost and they do not contain spending proofs.
output_candidates: Vec<ErgoBoxCandidate, Global>box candidates to be created by this transaction
Implementations
impl UnsignedTransaction[src]
pub fn new(
inputs: Vec<UnsignedInput, Global>,
data_inputs: Vec<DataInput, Global>,
output_candidates: Vec<ErgoBoxCandidate, Global>
) -> UnsignedTransaction[src]
inputs: Vec<UnsignedInput, Global>,
data_inputs: Vec<DataInput, Global>,
output_candidates: Vec<ErgoBoxCandidate, Global>
) -> UnsignedTransaction
Creates new transaction
pub fn id(&self) -> TxId[src]
Get transaction id
pub fn bytes_to_sign(&self) -> Vec<u8, Global>[src]
message to be signed by the [Prover] (serialized tx)