[−][src]Struct ergo_headless_dapp_framework::box_spec::BoxSpec
A specification which specifies parameters of an ErgoBox.
This spec is used as a "source of truth" to both verify and find
ErgoBoxes which match the spec. This is often used for defining
Stages in multi-stage smart contract protocols, but can also be used
to define input boxes for Actions.
All fields are wrapped in Options to allow ignoring specifying
the field.
Implementations
impl BoxSpec[src]
Method definitions for BoxSpec that are WASM-compatible by default
and/or are wrapper functions for Rust methods so that they
are made WASM-compatible.
pub fn utxo_scan_json(&self) -> String[src]
pub fn modified_address(&self, address: Option<ErgoAddressString>) -> BoxSpec[src]
Returns a new BoxSpec with all fields exactly the same
except the address is set to the String provided as input.
This method is generally used to hone down a more generic
BoxSpec definition into a more specific one for your given
use case. Ie. Add a user's P2PK address to find boxes matching
the BoxSpec in their wallet.
pub fn w_verify_box(&self, wrapped_ergo_box: WErgoBox) -> bool[src]
impl BoxSpec[src]
Method definitions for BoxSpec that are intended to be used in
Rust.
pub fn new(
address: Option<ErgoAddressString>,
value_range: Option<Range<NanoErg>>,
registers: Vec<RegisterSpec>,
tokens: Vec<Option<TokenSpec>>
) -> BoxSpec[src]
address: Option<ErgoAddressString>,
value_range: Option<Range<NanoErg>>,
registers: Vec<RegisterSpec>,
tokens: Vec<Option<TokenSpec>>
) -> BoxSpec
Create a new basic BoxSpec with no predicate.
pub fn new_predicated(
address: Option<ErgoAddressString>,
value_range: Option<Range<NanoErg>>,
registers: Vec<RegisterSpec>,
tokens: Vec<Option<TokenSpec>>,
predicate: Option<fn(_: &ErgoBox) -> bool>
) -> BoxSpec[src]
address: Option<ErgoAddressString>,
value_range: Option<Range<NanoErg>>,
registers: Vec<RegisterSpec>,
tokens: Vec<Option<TokenSpec>>,
predicate: Option<fn(_: &ErgoBox) -> bool>
) -> BoxSpec
Create a new BoxSpec with a custom predicate defined.
pub fn ergo_tree(&self) -> Result<ErgoTree>[src]
Acquire the ErgoTree of the address in the BoxSpec
pub fn verify_box(&self, ergo_box: &ErgoBox) -> Result<()>[src]
Verify that a provided ErgoBox matches the spec
pub fn explorer_endpoint(&self, explorer_api_url: &str) -> Result<String>[src]
Generates a URL for the Ergo Explorer Backend API
to find boxes which may match your BoxSpec. This method uses
the explorer_api_url you provide as input which
must be formatted as such:
https://api.ergoplatform.com/api
This method is intended to be used in tandem with
process_explorer_response()
pub fn process_explorer_response(
&self,
explorer_response_body: &str
) -> Result<Vec<ErgoBox>>[src]
&self,
explorer_response_body: &str
) -> Result<Vec<ErgoBox>>
Using the response JSON (as a String) from the Ergo Explorer API
endpoint generated by the explorer_endpoint() method,
filter all returned ErgoBoxes against the BoxSpec
using the verify_box() method.
impl BoxSpec[src]
Methods related to modifying fields (which aren't WASM-compatible)
pub fn modified_value_range(&self, value_range: Option<Range<u64>>) -> BoxSpec[src]
Returns a new BoxSpec with all fields exactly the same
except the value_range is set to the range provided as input.
pub fn modified_registers(&self, registers: Vec<RegisterSpec>) -> BoxSpec[src]
Returns a new BoxSpec with all fields exactly the same
except the registers are set to the registers provided as input.
pub fn modified_tokens(&self, tokens: Vec<Option<TokenSpec>>) -> BoxSpec[src]
Returns a new BoxSpec with all fields exactly the same
except the tokens are set to the TokenSpecs provided as input.
pub fn modified_predicate(
&self,
predicate: Option<fn(_: &ErgoBox) -> bool>
) -> BoxSpec[src]
&self,
predicate: Option<fn(_: &ErgoBox) -> bool>
) -> BoxSpec
Returns a new BoxSpec with all fields exactly the same
except the predicate is set to the one provided as input.